@@ -57,17 +57,36 @@ class OclConstants(object):
     }
 
     @staticmethod
-    def get_owner_url(owner_id='', owner_type=RESOURCE_TYPE_ORGANIZATION):
-        if owner_type not in OclConstants.OWNER_TYPE_TO_STEM:
-            raise Exception('Invalid owner type "%s"' % owner_type)
-        return '/%s/%s' % (OclConstants.OWNER_TYPE_TO_STEM[owner_type], owner_id)
+    def get_owner_type_stem(owner_type):
+        if owner_type in OclConstants.OWNER_TYPE_TO_STEM:
+            return OclConstants.OWNER_TYPE_TO_STEM[owner_type]
+        return ''
 
     @staticmethod
-    def get_repository_url(owner_id='', repository_id='',
+    def get_owner_url(owner_id='', include_trailing_slash=False,
+                      owner_type=RESOURCE_TYPE_ORGANIZATION):
+        if owner_type not in OclConstants.OWNER_TYPE_TO_STEM:
+            raise Exception('Invalid owner type "%s"' % owner_type)
+        owner_url = '/%s/%s' % (OclConstants.OWNER_TYPE_TO_STEM[owner_type], owner_id)
+        if include_trailing_slash:
+            owner_url += '/'
+        return owner_url
+
+    @staticmethod
+    def get_repo_type_stem(repo_type):
+        if repo_type in OclConstants.REPO_TYPE_TO_STEM:
+            return OclConstants.REPO_TYPE_TO_STEM[repo_type]
+        return ''
+
+    @staticmethod
+    def get_repository_url(owner_id='', repository_id='', include_trailing_slash=False,
                            owner_type=RESOURCE_TYPE_ORGANIZATION,
                            repository_type=RESOURCE_TYPE_SOURCE):
         owner_url = OclConstants.get_owner_url(owner_id=owner_id, owner_type=owner_type)
         if repository_type not in OclConstants.REPO_TYPE_TO_STEM:
             raise Exception('Invalid repository type "%s"' % repository_type)
-        return '%s/%s/%s' % (
+        repo_url = '%s/%s/%s' % (
             owner_url, OclConstants.REPO_TYPE_TO_STEM[repository_type], repository_id)
+        if include_trailing_slash:
+            repo_url += '/'
+        return repo_url
