@@ -281,6 +281,7 @@ class OclCsvToJsonConverter(object):
 
             # Handle to_concept_url based on Internal or External map target
             if map_target == oclconstants.OclConstants.MAPPING_TARGET_INTERNAL:
+                # JSON internal mapping requires map_type, from_concept_url, and to_concept_url
                 ocl_resource['to_concept_url'] = OclCsvToJsonConverter.get_concept_url(
                     concept_url=ocl_resource.pop('to_concept_url', ''),
                     owner_id=ocl_resource.pop('to_concept_owner_id', ''),
@@ -289,10 +290,20 @@ class OclCsvToJsonConverter(object):
                         oclconstants.OclConstants.RESOURCE_TYPE_ORGANIZATION),
                     source=ocl_resource.pop('to_concept_source', ''),
                     concept_id=ocl_resource.pop('to_concept_id', ''))
-            elif 'to_concept_url' in ocl_resource and ocl_resource['to_concept_url']:
-                err_msg = ('External mapping must not have a '
-                           '"to_concept_url": %s' % ocl_resource['to_concept_url'])
-                raise Exception(err_msg)
+            elif map_target == oclconstants.OclConstants.MAPPING_TARGET_EXTERNAL:
+                # JSON external mapping needs map_type, from_concept_url, to_source_url and
+                # to_concept_code. to_concept_name is optional.
+                if 'to_concept_url' in ocl_resource and ocl_resource['to_concept_url']:
+                    err_msg = ('External mapping must not have a '
+                               '"to_concept_url": %s' % ocl_resource['to_concept_url'])
+                    raise Exception(err_msg)
+                ocl_resource['to_source_url'] = OclCsvToJsonConverter._get_external_mapping_to_source_url(
+                    to_source_url=ocl_resource.pop('to_concept_url', ''),
+                    to_concept_owner_id=ocl_resource.pop('to_concept_owner_id', ''),
+                    to_concept_owner_type=ocl_resource.pop(
+                        'to_concept_owner_type',
+                        oclconstants.OclConstants.RESOURCE_TYPE_ORGANIZATION),
+                    to_concept_source=ocl_resource.pop('to_concept_source', ''))
 
         # Set sub-resources, eg concept names/descriptions
         if self.DEF_SUB_RESOURCES in csv_resource_def and csv_resource_def[self.DEF_SUB_RESOURCES]:
@@ -523,6 +534,15 @@ class OclCsvToJsonConverter(object):
             elif len(new_field_prefixes) == 1:
                 resource_def_template[new_field_name] = new_field_prefixes[0]
 
+    @staticmethod
+    def _get_external_mapping_to_source_url(to_source_url='', to_concept_owner_id='',
+                                            to_concept_owner_type='', to_concept_source=''):
+        if to_source_url:
+            return to_source_url
+        return oclconstants.OclConstants.get_repository_url(
+            owner_id=to_concept_owner_id, repository_id=to_concept_source,
+            owner_type=to_concept_owner_type, include_trailing_slash=True)
+
     @staticmethod
     def generate_resource_def_from_template(index_prefix, index_postfix, auto_resource_index,
                                             resource_def_template):
@@ -957,7 +977,7 @@ class OclStandardCsvToJsonConverter(OclCsvToJsonConverter):
                      'column_prefix': 'map_from_concept_source', 'required': False},
                     {'resource_field': 'to_concept_url', 'column_prefix': 'map_to_concept_url',
                      'required': False},
-                    {'resource_field': 'to_concept_id', 'column_prefix': 'map_to_concept_id',
+                    {'resource_field': 'to_concept_code', 'column_prefix': 'map_to_concept_id',
                      'required': False},
                     {'resource_field': 'to_concept_name', 'column_prefix': 'map_to_concept_name',
                      'required': False},
@@ -1008,7 +1028,7 @@ class OclStandardCsvToJsonConverter(OclCsvToJsonConverter):
                      'column_prefix': 'extmap_from_concept_source', 'required': False},
                     {'resource_field': 'to_concept_url', 'column_prefix': 'extmap_to_concept_url',
                      'required': False},
-                    {'resource_field': 'to_concept_id', 'column_prefix': 'extmap_to_concept_id',
+                    {'resource_field': 'to_concept_code', 'column_prefix': 'extmap_to_concept_id',
                      'required': False},
                     {'resource_field': 'to_concept_name', 'column_prefix': 'extmap_to_concept_name',
                      'required': False},
@@ -1019,6 +1039,8 @@ class OclStandardCsvToJsonConverter(OclCsvToJsonConverter):
                      'default': oclconstants.OclConstants.RESOURCE_TYPE_ORGANIZATION},
                     {'resource_field': 'to_concept_source', 'column': 'source',
                      'column_prefix': 'extmap_to_concept_source', 'required': False},
+                    {'resource_field': 'to_source_url', 'column_prefix': 'extmap_to_source_url',
+                     'required': False},
                     {'resource_field': 'owner', 'column_prefix': 'extmap_owner_id',
                      'column': 'owner_id'},
                     {'resource_field': 'owner_type', 'column_prefix': 'extmap_owner_type',
@@ -1089,7 +1111,7 @@ class OclStandardCsvToJsonConverter(OclCsvToJsonConverter):
                  'column': ['map_from_concept_source', 'from_concept_source', 'source']},
                 {'resource_field': 'to_concept_url', 'required': False,
                  'column': ['map_to_concept_url', 'to_concept_url']},
-                {'resource_field': 'to_concept_id', 'required': False,
+                {'resource_field': 'to_concept_code', 'required': False,
                  'column': ['map_to_concept_id', 'to_concept_id']},
                 {'resource_field': 'to_concept_name', 'required': False,
                  'column': ['map_to_concept_name', 'to_concept_name']},
@@ -1129,7 +1151,7 @@ class OclStandardCsvToJsonConverter(OclCsvToJsonConverter):
                  'default': oclconstants.OclConstants.RESOURCE_TYPE_ORGANIZATION},
                 {'resource_field': 'from_concept_source', 'required': False,
                  'column': ['map_from_concept_source', 'from_concept_source', 'source']},
-                {'resource_field': 'to_concept_id', 'required': False,
+                {'resource_field': 'to_concept_code', 'required': False,
                  'column': ['map_to_concept_id', 'to_concept_id']},
                 {'resource_field': 'to_concept_name', 'required': False,
                  'column': ['map_to_concept_name', 'to_concept_name']},
